@@ -86,7 +86,7 @@ class SquareletClient:
             timeout=self.timeout,
         )
 
-        if response.status_code == 401:
+        if response.status_code == "401":
             raise CredentialsFailedError("The username and password are incorrect")
 
         self.raise_for_status(response)
@@ -122,7 +122,7 @@ class SquareletClient:
         # Merge custom kwargs (headers, etc.) with the default kwargs
         kwargs.update(custom_kwargs)
 
-        # Track if we should set tokens in case of 401/403/429 response
+        # Track if we should set tokens in case of 403/429 response
         set_tokens = kwargs.pop("set_tokens", True)
         full_url = kwargs.pop("full_url", False)
 
@@ -134,8 +134,7 @@ class SquareletClient:
         )
         logger.debug("response: %s - %s", response.status_code, response.content)
 
-        if response.status_code in [401, 403, 429] and set_tokens:
-            logger.debug("Refreshing tokens due to 403/429")
+        if response.status_code in [403, 429] and set_tokens:
             self._set_tokens()  # Refresh tokens
             kwargs["set_tokens"] = False  # Prevent infinite loop
             return self.request(
@@ -154,11 +153,6 @@ class SquareletClient:
             "headers": kwargs.get("headers", {}),
         }
 
-        # Add version=2.0 only if not already present
-        if self.base_uri == "https://api.www.documentcloud.org/api/":
-            if "version" not in custom_kwargs["params"]:
-                custom_kwargs["params"]["version"] = "2.0"
-
         # Allow users to add custom params or headers by passing additional kwargs
         # Merge user-provided arguments with the defaults in custom_kwargs
         if "params" in kwargs:
